@@ -1,7 +1,9 @@
 from .area import Area
 from .box import Box
+from .bubble import Bubble
 from .heatmap import Heat
 from .histogram import Hist
+from .line import line
 from .pie import Pie
 from .pyramid import Pyra
 from .radar import Radar
