@@ -137,14 +137,14 @@ class Bubble:
         
 
 
-    def get_cwd(self):
-        # get the current path of file .
-        if platform.system().lower() == 'windows':
-            path = os.getcwd() + '/'
-
-        elif platform.system().lower() == 'linux':
-            path = os.getcwd().replace('/', '\\') + '/'
-        return path
+    # def get_cwd(self):
+    #     # get the current path of file .
+    #     if platform.system().lower() == 'windows':
+    #         path = os.getcwd() + '/'
+    #
+    #     elif platform.system().lower() == 'linux':
+    #         path = os.getcwd().replace('/', '\\') + '/'
+    #     return path
 
     def read_file(self, file, path):
         """Read different types of files and return pandas dataframe.
@@ -212,20 +212,20 @@ class Bubble:
                       fontsize=conf['labeltext_size'],
                       labelpad=conf['labelpad'])
 
-    def pic_save(self, conf,output_name):
+    # def pic_save(self, conf,output_name):
         # save the picture in specific file type
 
-        # xtricks and yticks font size
-        plt.xticks(fontsize=self.conf['xtrick_fontsize'])
-        plt.yticks(fontsize=self.conf['ytrick_fontsize'])
-
-        # title
-        # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
-
-        # save the plot
-
-        plt.savefig(output_name)
-        plt.show()
+        # # xtricks and yticks font size
+        # plt.xticks(fontsize=self.conf['xtrick_fontsize'])
+        # plt.yticks(fontsize=self.conf['ytrick_fontsize'])
+        #
+        # # title
+        # # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
+        #
+        # # save the plot
+        #
+        # plt.savefig(output_name)
+        # plt.show()
 
     # def conf_setting(self, key, value):
     #     self.conf_set.update(key / value)
@@ -273,8 +273,8 @@ class Bubble:
             bubble_name = header_list[0]
         # if path is None:
         #     path = self.path
-        if path_img is None:
-            path_img = path
+        # if path_img is None:
+        #     path_img = path
 
         conf = {
             # 'bubble_colors': [
@@ -351,7 +351,17 @@ class Bubble:
                             title=conf['bubbleszie_legend_title'],
                             fontsize=conf['legend_size'])
 
-        self.pic_save(conf, path_img)
+        # xtricks and yticks font size
+        plt.xticks(fontsize=self.conf['xtrick_fontsize'])
+        plt.yticks(fontsize=self.conf['ytrick_fontsize'])
+
+        # title
+        # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
+
+        # save the plot
+
+        plt.savefig(output_name)
+        plt.show()
 
     def bubble_category(self, file, path=None, file_type='.pdf', path_img=None, x_col_name=None, y_col_name=None,
                         bubble_col=None,
@@ -394,10 +404,10 @@ class Bubble:
             bubble_col = header_list[3]
         if category_col is None:
             category_col = header_list[0]
-        if path is None:
-            path = self.path
-        if path_img is None:
-            path_img = path
+        # if path is None:
+        #     path = self.path
+        # if path_img is None:
+        #     path_img = path
 
         conf = {
             # 'bubble_colors': [
@@ -458,7 +468,17 @@ class Bubble:
         # crate the legend
         ax.legend(handles=match_color, fontsize=self.conf['legend_size'])
 
-        self.pic_save(conf, path_img, output_name, file_type)
+        # xtricks and yticks font size
+        plt.xticks(fontsize=self.conf['xtrick_fontsize'])
+        plt.yticks(fontsize=self.conf['ytrick_fontsize'])
+
+        # title
+        # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
+
+        # save the plot
+
+        plt.savefig(output_name)
+        plt.show()
 
     def bubble_colormap(self, file, path=None, file_type='.pdf', path_img=None, x_col_name=None, y_col_name=None,
                         bubble_col=None,
@@ -493,10 +513,10 @@ class Bubble:
             y_col_name = header_list[2]
         if bubble_col is None:
             bubble_col = header_list[3]
-        if path is None:
-            path = self.path
-        if path_img is None:
-            path_img = path
+        # if path is None:
+        #     path = self.path
+        # if path_img is None:
+        #     path_img = path
 
         conf = {
             # 'bubble_size':
@@ -533,7 +553,17 @@ class Bubble:
         cbar = plt.colorbar(ax=ax)
         cbar.ax.tick_params(labelsize=conf['colorbar_labelsize'])
 
-        self.pic_save(conf, path_img, output_name, file_type)
+        # xtricks and yticks font size
+        plt.xticks(fontsize=self.conf['xtrick_fontsize'])
+        plt.yticks(fontsize=self.conf['ytrick_fontsize'])
+
+        # title
+        # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
+
+        # save the plot
+
+        plt.savefig(output_name)
+        plt.show()
 
 
 
